# select controls
# create AttributeCollection

import maya.cmds as mc
import mocapx.commands as mcpx_cmds
from mocapx.lib.nodes import get_poselib_node, get_selected_attrs


def generate_poses(poselib=None):
    selection = mc.ls(sl=True)

    if not selection:
        raise RuntimeError("Nothing selected.")

    if poselib is None:
        poselib_nodes = mc.ls(et="MCPXPoselib")

        if not poselib_nodes:
            poselib = get_poselib_node(create_node=True)
        elif len(poselib_nodes) == 1:
            poselib = poselib_nodes[0]
        else:
            raise RuntimeError("Parameter 'poselib' required.")

    time_range = map(int, (
    mc.playbackOptions(q=True, min=True), mc.playbackOptions(q=True, max=True) + 1.0))

    for frame in range(*time_range):
        mc.currentTime(frame, e=True)

        pose = mcpx_cmds.create_empty_pose(pose_name="f{}_pose".format(frame))
        mc.select(selection, r=True)
        selected_attrs = get_selected_attrs()
        if selected_attrs:
            mcpx_cmds.update_plugs_in_pose(pose, selected_plugs=True)
        else:
            mcpx_cmds.update_controls_in_pose(pose, selected_controls=True)
        mcpx_cmds.add_pose_to_poselib(poselib, [pose])

    mc.currentTime(time_range[0], e=True)


generate_poses(poselib=None)

mc.rename("f1_pose", "eyeBlink_L")
mc.rename("f2_pose", "eyeBlink_R")
mc.rename("f3_pose", "eyeLookDown_L")
mc.rename("f4_pose", "eyeLookDown_R")
mc.rename("f5_pose", "eyeLookIn_L")
mc.rename("f6_pose", "eyeLookIn_R")
mc.rename("f7_pose", "eyeLookOut_L")
mc.rename("f8_pose", "eyeLookOut_R")
mc.rename("f9_pose", "eyeLookUp_L")
mc.rename("f10_pose", "eyeLookUp_R")
mc.rename("f11_pose", "eyeSquint_L")
mc.rename("f12_pose", "eyeSquint_R")
mc.rename("f13_pose", "eyeWide_L")
mc.rename("f14_pose", "eyeWide_R")
mc.rename("f15_pose", "jawForward")
mc.rename("f16_pose", "jawLeft")
mc.rename("f17_pose", "jawRight")
mc.rename("f18_pose", "jawOpen")
mc.rename("f19_pose", "mouthClose")
mc.rename("f20_pose", "mouthFunnel")
mc.rename("f21_pose", "mouthPucker")
mc.rename("f22_pose", "mouthLeft")
mc.rename("f23_pose", "mouthRight")
mc.rename("f24_pose", "mouthSmile_L")
mc.rename("f25_pose", "mouthSmile_R")
mc.rename("f26_pose", "mouthFrown_L")
mc.rename("f27_pose", "mouthFrown_R")
mc.rename("f28_pose", "mouthDimple_L")
mc.rename("f29_pose", "mouthDimple_R")
mc.rename("f30_pose", "mouthStretch_L")
mc.rename("f31_pose", "mouthStretch_R")
mc.rename("f32_pose", "mouthRollLower")
mc.rename("f33_pose", "mouthRollUpper")
mc.rename("f34_pose", "mouthShrugLower")
mc.rename("f35_pose", "mouthShrugUpper")
mc.rename("f36_pose", "mouthPress_L")
mc.rename("f37_pose", "mouthPress_R")
mc.rename("f38_pose", "mouthLowerDown_L")
mc.rename("f39_pose", "mouthLowerDown_R")
mc.rename("f40_pose", "mouthUpperUp_L")
mc.rename("f41_pose", "mouthUpperUp_R")
mc.rename("f42_pose", "browDown_L")
mc.rename("f43_pose", "browDown_R")
mc.rename("f44_pose", "browInnerUp")
mc.rename("f45_pose", "browOuterUp_L")
mc.rename("f46_pose", "browOuterUp_R")
mc.rename("f47_pose", "cheekPuff")
mc.rename("f48_pose", "cheekSquint_L")
mc.rename("f49_pose", "cheekSquint_R")
mc.rename("f50_pose", "noseSneer_L")
mc.rename("f51_pose", "noseSneer_R")
mc.rename("f52_pose", "tongueOut")

